@@ -2,7 +2,7 @@
 Base class for Scrapy commands
 """
 import os
-from optparse import OptionGroup
+import argparse
 from typing import Any, Dict
 
 from twisted.python import failure
@@ -43,14 +43,14 @@ class ScrapyCommand:
 
     def long_desc(self):
         """A long description of the command. Return short description when not
-        available. It cannot contain newlines, since contents will be formatted
+        available. It cannot contain newlines since contents will be formatted
         by optparser which removes newlines and wraps text.
         """
         return self.short_desc()
 
     def help(self):
         """An extensive help for the command. It will be shown when using the
-        "help" command. It can contain newlines, since no post-formatting will
+        "help" command. It can contain newlines since no post-formatting will
         be applied to its contents.
         """
         return self.long_desc()
@@ -59,22 +59,20 @@ class ScrapyCommand:
         """
         Populate option parse with options available for this command
         """
-        group = OptionGroup(parser, "Global Options")
-        group.add_option("--logfile", metavar="FILE",
-                         help="log file. if omitted stderr will be used")
-        group.add_option("-L", "--loglevel", metavar="LEVEL", default=None,
-                         help=f"log level (default: {self.settings['LOG_LEVEL']})")
-        group.add_option("--nolog", action="store_true",
-                         help="disable logging completely")
-        group.add_option("--profile", metavar="FILE", default=None,
-                         help="write python cProfile stats to FILE")
-        group.add_option("--pidfile", metavar="FILE",
-                         help="write process ID to FILE")
-        group.add_option("-s", "--set", action="append", default=[], metavar="NAME=VALUE",
-                         help="set/override setting (may be repeated)")
-        group.add_option("--pdb", action="store_true", help="enable pdb on failure")
-
-        parser.add_option_group(group)
+        group = parser.add_argument_group(title='Global Options')
+        group.add_argument("--logfile", metavar="FILE",
+                           help="log file. if omitted stderr will be used")
+        group.add_argument("-L", "--loglevel", metavar="LEVEL", default=None,
+                           help=f"log level (default: {self.settings['LOG_LEVEL']})")
+        group.add_argument("--nolog", action="store_true",
+                           help="disable logging completely")
+        group.add_argument("--profile", metavar="FILE", default=None,
+                           help="write python cProfile stats to FILE")
+        group.add_argument("--pidfile", metavar="FILE",
+                           help="write process ID to FILE")
+        group.add_argument("-s", "--set", action="append", default=[], metavar="NAME=VALUE",
+                           help="set/override setting (may be repeated)")
+        group.add_argument("--pdb", action="store_true", help="enable pdb on failure")
 
     def process_options(self, args, opts):
         try:
@@ -114,14 +112,14 @@ class BaseRunSpiderCommand(ScrapyCommand):
     """
     def add_options(self, parser):
         ScrapyCommand.add_options(self, parser)
-        parser.add_option("-a", dest="spargs", action="append", default=[], metavar="NAME=VALUE",
-                          help="set spider argument (may be repeated)")
-        parser.add_option("-o", "--output", metavar="FILE", action="append",
-                          help="append scraped items to the end of FILE (use - for stdout)")
-        parser.add_option("-O", "--overwrite-output", metavar="FILE", action="append",
-                          help="dump scraped items into FILE, overwriting any existing file")
-        parser.add_option("-t", "--output-format", metavar="FORMAT",
-                          help="format to use for dumping items")
+        parser.add_argument("-a", dest="spargs", action="append", default=[], metavar="NAME=VALUE",
+                            help="set spider argument (may be repeated)")
+        parser.add_argument("-o", "--output", metavar="FILE", action="append",
+                            help="append scraped items to the end of FILE (use - for stdout)")
+        parser.add_argument("-O", "--overwrite-output", metavar="FILE", action="append",
+                            help="dump scraped items into FILE, overwriting any existing file")
+        parser.add_argument("-t", "--output-format", metavar="FORMAT",
+                            help="format to use for dumping items")
 
     def process_options(self, args, opts):
         ScrapyCommand.process_options(self, args, opts)
@@ -137,3 +135,30 @@ class BaseRunSpiderCommand(ScrapyCommand):
                 opts.overwrite_output,
             )
             self.settings.set('FEEDS', feeds, priority='cmdline')
+
+
+class ScrapyHelpFormatter(argparse.HelpFormatter):
+    """
+    Help Formatter for scrapy command line help messages.
+    """
+    def __init__(self, prog, indent_increment=2, max_help_position=24, width=None):
+        super().__init__(prog, indent_increment=indent_increment,
+                         max_help_position=max_help_position, width=width)
+
+    def _join_parts(self, part_strings):
+        parts = self.format_part_strings(part_strings)
+        return super()._join_parts(parts)
+
+    def format_part_strings(self, part_strings):
+        """
+        Underline and title case command line help message headers.
+        """
+        if part_strings and part_strings[0].startswith("usage: "):
+            part_strings[0] = "Usage\n=====\n  " + part_strings[0][len('usage: '):]
+        headings = [i for i in range(len(part_strings)) if part_strings[i].endswith(':\n')]
+        for index in headings[::-1]:
+            char = '-' if "Global Options" in part_strings[index] else '='
+            part_strings[index] = part_strings[index][:-2].title()
+            underline = ''.join(["\n", (char * len(part_strings[index])), "\n"])
+            part_strings.insert(index + 1, underline)
+        return part_strings
